==> zio-aws-macie2_2.12-5.17.123.1-sources.jar: zio/aws/macie2/model/JobScopingBlock.scala <==
package zio.aws.macie2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class JobScopingBlock(
    and: Option[Iterable[zio.aws.macie2.model.JobScopeTerm]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.macie2.model.JobScopingBlock = {
    import JobScopingBlock.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.macie2.model.JobScopingBlock
      .builder()
      .optionallyWith(
        and.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.and)
      .build()
  }
  def asReadOnly: zio.aws.macie2.model.JobScopingBlock.ReadOnly =
    zio.aws.macie2.model.JobScopingBlock.wrap(buildAwsValue())
}
object JobScopingBlock {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.macie2.model.JobScopingBlock
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.macie2.model.JobScopingBlock =
      zio.aws.macie2.model.JobScopingBlock(
        and.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def and: Option[List[zio.aws.macie2.model.JobScopeTerm.ReadOnly]]
    def getAnd
        : ZIO[Any, AwsError, List[zio.aws.macie2.model.JobScopeTerm.ReadOnly]] =
      AwsError.unwrapOptionField("and", and)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.macie2.model.JobScopingBlock
  ) extends zio.aws.macie2.model.JobScopingBlock.ReadOnly {
    override val and: Option[List[zio.aws.macie2.model.JobScopeTerm.ReadOnly]] =
      scala
        .Option(impl.and())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.macie2.model.JobScopeTerm.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.macie2.model.JobScopingBlock
  ): zio.aws.macie2.model.JobScopingBlock.ReadOnly = new Wrapper(impl)
}

==> zio-aws-macie2_2.13-5.17.164.1-sources.jar: zio/aws/macie2/model/JobScopingBlock.scala <==
package zio.aws.macie2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class JobScopingBlock(
    and: Optional[Iterable[zio.aws.macie2.model.JobScopeTerm]] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.macie2.model.JobScopingBlock = {
    import JobScopingBlock.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.macie2.model.JobScopingBlock
      .builder()
      .optionallyWith(
        and.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.and)
      .build()
  }
  def asReadOnly: zio.aws.macie2.model.JobScopingBlock.ReadOnly =
    zio.aws.macie2.model.JobScopingBlock.wrap(buildAwsValue())
}
object JobScopingBlock {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.macie2.model.JobScopingBlock
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.macie2.model.JobScopingBlock =
      zio.aws.macie2.model.JobScopingBlock(
        and.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def and: Optional[List[zio.aws.macie2.model.JobScopeTerm.ReadOnly]]
    def getAnd
        : ZIO[Any, AwsError, List[zio.aws.macie2.model.JobScopeTerm.ReadOnly]] =
      AwsError.unwrapOptionField("and", and)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.macie2.model.JobScopingBlock
  ) extends zio.aws.macie2.model.JobScopingBlock.ReadOnly {
    override val and
        : Optional[List[zio.aws.macie2.model.JobScopeTerm.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.and())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.macie2.model.JobScopeTerm.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.macie2.model.JobScopingBlock
  ): zio.aws.macie2.model.JobScopingBlock.ReadOnly = new Wrapper(impl)
}
